=begin (comment block)

TROG STYLE CHOOSER
v1.0
23 November 2012

Adds a sub-menu to the 'View' menu allowing four favourite styles to be stored and
recalled - and thus assigned to shortcut keys.  The four selected styles are remembered
between sessions using a small file stored in the "Trog_Styles_Chooser" directory that
is created within the Sketchup Plugins folder (this will require the user to have full
read write permission for that directory!!)

Note that the four chosen styles are remembered by name, and must be resident in the
current model (I added my four favourites to my default template style).  'Recall' items
in the sub-menu will be greyed out if no style has yet been chosen, or if the named
style cannot be found.

If you want more or fewer favourites memories, edit the constant "Max_styles" in the module
header.

=end

require("sketchup")

module Trog

	Max_styles = 4
	
	# Set file paths and make a directory fi there isn't one yet
	Styles_dir = File.join(File.dirname(__FILE__), 'Trog_Styles_Chooser')
	Styles_path = File.join(Styles_dir, 'Trog_Styles.dump')
	Dir.mkdir(Styles_dir) unless File.exist?(Styles_dir)
	
	#Load favourites at startup
	@@styles = if File.exists?(Styles_path)
		File.open(Styles_path) do |file|
			Marshal.load(file)
		end
	else
		[]  # empty selection of styles if the file is not found
	end
	
	def self.style_exists?(index)
	# Finds out if the named style exists in the currently active
	# model.  If so, return the style object, otherwise nil.
		styles = Sketchup.active_model.styles
		styles.each do |style|
			return style if style.name == @@styles[index]
		end
		return nil
	end
	
	def self.style_store(index)
	# Takes the currently active style and assigns it to the favourites
	# list at the chosen index.  This is then auto-saved to the file
		return nil unless (0...Max_styles)===index
		@@styles[index] = Sketchup.active_model.styles.active_style.name
		File.open(Styles_path,"w") do |file|
			Marshal.dump(@@styles,file)
		end
	end
	
	def self.style_load(index)
	# If index is in range, loads the style stored at that index.
	# Return value is inherited from .style_select
		return nil unless (0...Max_styles)===index
		styles = Sketchup.active_model.styles
		if (found=style_exists?(index)) then styles.selected_style = found end
		return found
	end	

	# Add sketchup menu items
	
	unless file_loaded?("Trog_Style_Chooser.rb")
		
		#Within "View" Menu
		edit_menu = UI.menu("View")
		edit_menu.add_separator
		my_menu = edit_menu.add_submenu("Style Favourites")
		
			#Sub menus - Recall
			(0...Max_styles).each do |index|
				item = my_menu.add_item("Recall #{index+1}"){self.style_load(index)}
				my_menu.set_validation_proc(item){
				if self.style_exists?(index)
					MF_ENABLED
				else
					MF_GRAYED
				end}
			end
			my_menu.add_separator
			
			#Sub menus - Store
			(0...Max_styles).each do |index|
				my_menu.add_item("Store #{index+1}"){self.style_store(index)}
			end

	end

	file_loaded("Trog_Style_Chooser.rb")

end #module Trog



	